import WebSocket from 'ws';
import { EventEmitter } from 'events';
import { ActionContext, ActionResult } from './context';
import { ToolkitAPI } from './api';
interface ActionHandler {
    func: (ctx: ActionContext, payload: any, payment?: number) => Promise<ActionResult> | ActionResult;
    actionDescription: string | object;
    payloadDescription: string | object;
    paymentDescription: string | object;
}
interface ToolkitConfig {
    apiKey: string;
    reconnectInterval?: number;
}
export declare class Toolkit extends EventEmitter {
    private apiKey;
    wsEndpoint: string;
    ws: WebSocket | null;
    reconnectInterval: number;
    actionHandlers: {
        [key: string]: ActionHandler;
    };
    api: ToolkitAPI;
    constructor({ apiKey, reconnectInterval }: ToolkitConfig);
    /**
     * Set the WebSocket endpoint for the toolkit.
     *
     * @param endpoint - The WebSocket endpoint URL
     */
    setWsEndpoint(endpoint: string): void;
    /**
     * Set the API endpoint for the toolkit.
     *
     * @param endpoint - The API endpoint URL
     */
    setApiEndpoint(endpoint: string): void;
    /**
     * Register an action handler.
     *
     * @param config - Configuration for the action.
     * @param handler - The handler function.
     */
    action(config: {
        action: string;
        actionDescription?: string | object;
        payloadDescription?: string | object;
        paymentDescription?: string | object;
    }, handler: (ctx: ActionContext, payload: any, payment?: number) => Promise<ActionResult> | ActionResult): void;
    event(eventName: string, handler: (...args: any[]) => void): void;
    /**
     * Update the toolkit's name and/or description.
     *
     * @param info - An object containing optional name and/or description for the toolkit
     * @param info.name - Optional new name for the toolkit
     * @param info.description - Optional new description for the toolkit
     */
    updateToolkit(info: {
        name?: string;
        description?: string;
    }): Promise<void>;
    private handleAction;
    private handleMessage;
    private connect;
    /**
     * Start the toolkit client.
     */
    run(): Promise<void>;
}
export {};
