interface Function {
    name: string;
    description: string;
    parameters: {
        [key: string]: any;
    };
}
interface Tool {
    type: 'function';
    function: Function;
}
interface OpenAIFunctionCall {
    name: string;
    arguments: string;
}
interface OpenAIToolCall {
    id: string;
    type: string;
    function: OpenAIFunctionCall;
}
interface OpenAIToolResult {
    role: string;
    tool_call_id: string;
    content: string;
}
declare enum FunctionName {
    SEARCH_TOOLS = "search_tools",
    CALL_TOOL = "call_tool"
}
export declare const functionList: Function[];
interface ToolsConfig {
    apiKey: string;
}
export declare class Tools {
    private api;
    constructor({ apiKey }: ToolsConfig);
    /**
     * Set the API endpoint for the tools.
     *
     * @param endpoint - The API endpoint URL
     */
    setApiEndpoint(endpoint: string): void;
    getTools(): Tool[];
    callTool(name: string | FunctionName, args: any): Promise<any>;
    callTools(toolCalls?: OpenAIToolCall[] | null, concurrency?: number): Promise<OpenAIToolResult[]>;
}
export {};
