"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tools = exports.functionList = void 0;
const p_limit_1 = __importDefault(require("p-limit"));
const api_1 = require("./api");
var FunctionName;
(function (FunctionName) {
    FunctionName["SEARCH_TOOLS"] = "search_tools";
    FunctionName["CALL_TOOL"] = "call_tool";
})(FunctionName || (FunctionName = {}));
exports.functionList = [
    {
        name: FunctionName.SEARCH_TOOLS,
        description: 'Search for tools. The tools cover a wide range of domains include data source, API, SDK, etc. Try searching whenever you need to use a tool.',
        parameters: {
            type: 'object',
            properties: {
                query: {
                    type: 'string',
                    description: 'The query to search for tools, you can describe what you want to do or what tools you want to use'
                },
                limit: {
                    type: 'number',
                    description: 'The maximum number of tools to return, must be between 1 and 100, default is 10, recommend at least 10'
                }
            },
            required: ['query'],
        },
    },
    {
        name: FunctionName.CALL_TOOL,
        description: 'Call a tool returned by search_tools',
        parameters: {
            type: 'object',
            properties: {
                action: {
                    type: 'string',
                    description: 'The exact action you want to call in the search_tools result.'
                },
                payload: {
                    type: 'string',
                    description: 'Action payload, based on the payload schema in the search_tools result. You can pass either the json object directly or json encoded string of the object.',
                },
                payment: {
                    type: 'number',
                    description: 'Amount to authorize in USD. Positive number means you will be charged no more than this amount, negative number means you are requesting to get paid for at least this amount. Only include this field if the action you are calling includes payment information.',
                }
            },
            required: ['action', 'payload'],
        },
    },
];
const toolList = exports.functionList.map(func => ({
    type: 'function',
    function: func
}));
class Tools {
    constructor({ apiKey }) {
        this.api = new api_1.ToolsAPI({ apiKey });
    }
    /**
     * Set the API endpoint for the tools.
     *
     * @param endpoint - The API endpoint URL
     */
    setApiEndpoint(endpoint) {
        this.api.setEndpoint(endpoint);
    }
    getTools() {
        return toolList;
    }
    callTool(name, args) {
        return __awaiter(this, void 0, void 0, function* () {
            const toolName = typeof name === 'string' ? name : FunctionName[name];
            const params = typeof args === 'string' ? JSON.parse(args) : args;
            if (toolName === FunctionName.SEARCH_TOOLS) {
                return yield this.api.searchTools(params);
            }
            else if (toolName === FunctionName.CALL_TOOL) {
                return yield this.api.callTool(params);
            }
            else {
                console.warn(`Unknown tool name: ${toolName}`);
                return null;
            }
        });
    }
    callTools() {
        return __awaiter(this, arguments, void 0, function* (toolCalls = null, concurrency = 1) {
            if (!toolCalls)
                return [];
            const limit = (0, p_limit_1.default)(concurrency);
            const tasks = toolCalls.map(toolCall => limit(() => __awaiter(this, void 0, void 0, function* () {
                let result;
                try {
                    result = yield this.callTool(toolCall.function.name, toolCall.function.arguments);
                    if (result === null)
                        return null;
                }
                catch (error) {
                    result = { error: error instanceof Error ? error.message : String(error) };
                }
                return {
                    role: 'tool',
                    tool_call_id: toolCall.id,
                    content: JSON.stringify(result),
                };
            })));
            const results = yield Promise.all(tasks);
            return results.filter((result) => result !== null);
        });
    }
}
exports.Tools = Tools;
